@@ -25,6 +25,8 @@
 #include "bibformats.h"
 #include "generic.h"
 
+#include "R.h"
+
 static slist find    = { 0, 0, 0, NULL };
 static slist replace = { 0, 0, 0, NULL };
 
@@ -68,6 +70,11 @@ bibtexdirectin_initparams( param *pm, const char *progname )
 	slist_init( &(pm->asis) );
 	slist_init( &(pm->corps) );
 
+ 	// TODO: these probably should be made parameters, as the others above;
+	//       note that 'find' and 'replace' work in tandem, so both need to be cleared.
+	slist_free( &find );
+	slist_free( &replace );
+
 	if ( !progname ) pm->progname = NULL;
 	else {
 		pm->progname = strdup( progname );
@@ -178,6 +185,8 @@ process_bibtextype( const char *p, str *type )
 	return p;
 }
 
+char *dummy_id2 = "dummyid";
+
 static const char *
 process_bibtexid( const char *p, str *id )
 {
@@ -200,9 +209,15 @@ process_bibtexid( const char *p, str *id )
 			str_strcpy( id, &tmp );
 		}
 	} else {
-		str_empty( id );
+	  // Georgi was: str_empty( id );
+	  str_strcpyc( id, dummy_id2 );
 	}
 
+	str_trimstartingws(id);
+	str_trimendingws(id);
+	
+	// REprintf("id = %s, this should not be on new line\n", id->data);
+ 
 	str_free( &tmp );
 	return skip_ws( p );
 }
@@ -628,6 +643,7 @@ out:
 /* bibtexdirectin_processf()
  *
  * Handle '@STRING', '@reftype', and ignore '@COMMENT'
+ *                                   Georgi: also ignore @PREAMBLE
  */
 static int
 bibtexdirectin_processf( fields *bibin, const char *data, const char *filename, long nref, param *pm )
@@ -641,7 +657,10 @@ bibtexdirectin_processf( fields *bibin, const char *data, const char *filename,
 	if ( !strncasecmp( data, "@STRING", 7 ) ) {
 		process_string( data+7, &currloc );
 		return 0;
-	} else if ( !strncasecmp( data, "@COMMENT", 8 ) ) {
+	} else if ( !strncasecmp( data, "@COMMENT", 8 ) || !strncasecmp( data, "@PREAMBLE", 9 )) {
+	  // Georgi: added @PREAMBLE
+	  //    todo: It could make sense to keep it for output to bibtex (or TeX related)
+	  
 		/* Not sure if these are real Bibtex, but not references */
 		return 0;
 	} else {
@@ -744,10 +763,15 @@ bibtex_person_tokenize( fields *bibin, int m, param *pm, slist *tokens )
 	int i, ok, status;
 	str *s;
 
-// REprintf("person!\n");
+	
 	status = latex_tokenize( tokens, fields_value( bibin, m, FIELDS_STRP ) );
 	if ( status!=BIBL_OK ) return status;
 
+// REprintf("\nbibtex_person_tokenize: person!\n");
+//  REprintf("number of tokens: %d\n", tokens->n);
+// 		for ( i=0; i<tokens->n; ++i )
+// 			REprintf( "%s\n", slist_cstr( tokens, i ) );
+// REprintf("\nbibtex_person_tokenize: person! --------------\n");
 
 	for ( i=0; i<tokens->n; ++i ) {
 
@@ -776,6 +800,12 @@ bibtex_person_tokenize( fields *bibin, int m, param *pm, slist *tokens )
 
 	}
 
+// REprintf("\nbibtex_person_tokenize: person!\n");
+//  REprintf("number of tokens: %d\n", tokens->n);
+// 		for ( i=0; i<tokens->n; ++i )
+// 			REprintf( "%s\n", slist_cstr( tokens, i ) );
+// REprintf("\nbibtex_person_tokenize: person! --------------\n");
+	
 	return BIBL_OK;
 }
 
@@ -790,7 +820,7 @@ bibtex_person_add_names( fields *bibin, int m, slist *tokens )
 	int begin, end, ok, n, etal;
 
 	etal = name_findetal( tokens );
-// REprintf("person_add_names!\n");
+	// REprintf("person_add_names!\n");
 
 	begin = 0;
 	n = tokens->n - etal;
@@ -823,6 +853,8 @@ bibtex_person_add_names( fields *bibin, int m, slist *tokens )
 		if ( !ok ) return BIBL_ERR_MEMERR;
 	}
 
+	// REprintf("person_add_names!(end)\n");
+ 
 	return BIBL_OK;
 }
 
@@ -845,7 +877,7 @@ bibtexdirectin_person( fields *bibin, int m, param *pm )
 	// int nout = fields_num( bibin );
 	// int i;
 	// if(nout > 0) {
-	//   REprintf("nout = %d\n" , nout);
+	//   REprintf("bibtexdirectin_person: nout = %d\n" , nout);
 	//   for(i = 0; i < nout; i++) {
 	//     REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
 	//   }
@@ -854,6 +886,13 @@ bibtexdirectin_person( fields *bibin, int m, param *pm )
 	status = bibtex_person_add_names( bibin, m, &tokens );
 	if ( status!=BIBL_OK ) goto out;
 
+	// nout = fields_num( bibin );
+	// if(nout > 0) {
+	//   REprintf("bibtexdirectin_person (end): nout = %d\n" , nout);
+	//   for(i = 0; i < nout; i++) {
+	//     REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
+	//   }
+	// }
 out:
 	slist_free( &tokens );
 	return status;
@@ -870,9 +909,8 @@ bibtexdirectin_cleanref( fields *bibin, param *pm )
 	intlist_init( &toremove );
 
 	n = fields_num( bibin );
-// REprintf("n = %d\n", n);
 
-	  // REprintf("n = %d\n" , n);
+	  // REprintf("\nbibtexdirectin_cleanref (start): n = %d\n" , n);
 	  // for(i = 0; i < n; i++) {
 	  //   REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
 	  // }
@@ -882,7 +920,7 @@ bibtexdirectin_cleanref( fields *bibin, param *pm )
 	for ( i=0; i<n; ++i ) {
 
 		tag = fields_tag( bibin, i, FIELDS_STRP_NOUSE );
-// REprintf("\ntag = %s\n", tag->data);
+		// REprintf("\nbibtexdirectin_cleanref: tag = %s", tag->data);
 		if ( is_url_tag( tag ) ) continue; /* protect url from parsing */
 
 		/* Georgi:  protecting names, otherwise havoc ensues if the input is 
@@ -905,8 +943,11 @@ bibtexdirectin_cleanref( fields *bibin, param *pm )
 		// }
 		if ( is_name_tag( tag ) ) {
 			status = bibtexdirectin_person( bibin, i, pm );
-// REprintf("\ni = %d, ", i);
+						
+// REprintf("\tbefore: i = %d, ", i);
 // REprintf("value = %s\n", (bibin->value[i]).data);
+// REprintf("\tafter:  newpos = %d, ", fields_num( bibin ) - 1);
+// REprintf("value = %s\n", (bibin->value[fields_num( bibin ) - 1]).data);
  
 			if ( status!=BIBL_OK ) goto out;
 
@@ -935,7 +976,7 @@ bibtexdirectin_cleanref( fields *bibin, param *pm )
 
 	// int nout = fields_num( bibin );
 	// if(nout > n) {
-	//   REprintf("nout = %d\n" , nout);
+	//   REprintf("\nbibtexdirectin_cleanref (2): nout = %d\n" , nout);
 	//   for(i = 0; i < nout; i++) {
 	//     REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
 	//   }
@@ -956,7 +997,7 @@ out:
 	
 	// nout = fields_num( bibin );
 	// if(nout > n) {
-	//   REprintf("nout = %d\n" , nout);
+	//   REprintf("\nbibtexdirectin_cleanref (end): nout = %d\n" , nout);
 	//   for(i = 0; i < nout; i++) {
 	//     REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
 	//   }
@@ -1064,3 +1105,7 @@ bibtexdirectin_typef( fields *bibin, const char *filename, int nrefs, param *p )
 
 	return get_reftype( typename, nrefs, p->progname, p->all, p->nall, refname, &is_default, REFTYPE_CHATTY );
 }
+
+
+
+
